/***************************************************************************
                          playlistitem.h  -  A self-displayable item for
			                   kaffeine's playlist
                             -------------------
    begin                : Mon Feb 16 2004
    revision             : $Revision: 1.2 $
    last modified        : $Date: 2004/09/04 19:11:46 $ by $Author: juergenk $        
    copyright            : (C) 2004 by Giorgos Gousios, Jürgen Kofler
    email                : kaffeine@gmx.net
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#include <qstringlist.h>  
 
#include "mrl.h"
#include "playlistitem.h"
 
PlaylistItem::PlaylistItem(KListView *list, KListViewItem *after, const QString& url, const QString& mime, const QString& title, 
             const QString& length, const QString& artist, const QString& album, const QString& year, const QString& genre,
             const QString& track, const QStringList& subtitles, int currentSubtitle) :
             KListViewItem(list, after, mime, title, artist, album, track, length), 
	     m_url(url), m_year(year), m_genre(genre), m_subtitles(subtitles), m_currentSubtitle(currentSubtitle)
{}  

PlaylistItem::PlaylistItem(KListView* list, KListViewItem* after, const MRL& mrl) :
                           KListViewItem(list, after, mrl.mime(), mrl.title(), mrl.artist(), mrl.album(), 
			   mrl.track(), mrl.length().toString("h:mm:ss")), m_url(mrl.url()), 
			   m_year(mrl.year()), m_genre(mrl.genre()),
			   m_subtitles(mrl.subtitleFiles()), m_currentSubtitle(mrl.currentSubtitle())
{}
  
PlaylistItem::~PlaylistItem() {}

MRL PlaylistItem::toMRL() const
{
  return MRL(url(), title(), stringToTime(length()), mime(), artist(), album(), track(), year(), genre(), QString::null, subtitles(), currentSubtitle());
}

const QString& PlaylistItem::url() const
{
  return m_url;
}

QString PlaylistItem::mime() const
{
  return this->text(0);
}

QString PlaylistItem::title() const
{
  return this->text(1);
}

QString PlaylistItem::artist() const
{
  return this->text(2);
}

QString PlaylistItem::album() const
{
  return this->text(3);
}

QString PlaylistItem::track() const
{
  return this->text(4);
}

QString PlaylistItem::year() const
{
  return m_year;
}

QString PlaylistItem::genre() const
{
  return m_genre;
}    

QString PlaylistItem::length() const
{
  return this->text(5);
}

const QStringList& PlaylistItem::subtitles() const
{
  return m_subtitles;
}

int PlaylistItem::currentSubtitle() const
{
  return m_currentSubtitle;
}  
   
void PlaylistItem::setUrl(const QString& url)
{
  m_url = url;
}

void PlaylistItem::setMime(const QString& mime)
{
  this->setText(0, mime);
}

void PlaylistItem::setTitle(const QString& title)
{
  this->setText(1, title);
}

void PlaylistItem::setArtist(const QString& artist)
{
  this->setText(2, artist);
}

void PlaylistItem::setAlbum(const QString& album)
{
  this->setText(3, album);
}

void PlaylistItem::setTrack(const QString& track)
{
  this->setText(4, track);
}

void PlaylistItem::setYear(const QString& year)
{
  m_year = year;
}

void PlaylistItem::setGenre(const QString& genre)
{
  m_genre = genre;
}    

void PlaylistItem::setLength(const QString& length)
{
  this->setText(5, length);
}

void PlaylistItem::setSubtitles(const QStringList& subs)
{
  m_subtitles = subs;
}

void PlaylistItem::addSubtitle(const QString& sub)
{
  m_subtitles.append(sub);
}

void PlaylistItem::setCurrentSubtitle(int sub)
{
  m_currentSubtitle = sub;
}

QTime PlaylistItem::stringToTime(const QString& timeString)
{
  int sec = 0;
  bool ok = false;
  QStringList tokens = QStringList::split(':',timeString);
  
  sec += tokens[0].toInt(&ok)*3600; //hours
  sec += tokens[1].toInt(&ok)*60; //minutes
  sec += tokens[2].toInt(&ok); //secs
  
  if (ok)
    return QTime().addSecs(sec);
   else
    return QTime(); 
}


